@@ -17,12 +17,16 @@
 # Author: Francois Boulogne <fboulogne at sciunto dot org>, 2012
 
 import os
-import psutil
+try:
+    import psutil
+except ImportError:
+    psutil = None
 #import signal
 import logging, logging.handlers
 import sys
 
-from Vitalus.job import Job, TARGETError
+from Vitalus.rsyncjob import RsyncJob
+from Vitalus.job import TARGETError
 import Vitalus.info as info
 
 
@@ -133,20 +137,22 @@ class Vitalus:
     def _set_process_high_priority(self):
         """ Change nice/ionice"""
         self.logger.debug('Set high priority')
-        #ionice
-        p = psutil.Process(os.getpid())
-        p.set_ionice(psutil.IOPRIO_CLASS_NONE, value=0)
-        #nice
-        p.nice = 10
+        if psutil and psutil.IOPRIO_CLASS_NONE:
+            #ionice
+            p = psutil.Process(os.getpid())
+            p.set_ionice(psutil.IOPRIO_CLASS_NONE, value=0)
+            #nice
+            p.nice = 10
 
     def _set_process_low_priority(self):
         """ Change nice/ionice"""
         self.logger.debug('Set low priority')
-        #ionice
-        p = psutil.Process(os.getpid())
-        p.set_ionice(psutil.IOPRIO_CLASS_IDLE)
-        #nice
-        p.nice = 15
+        if psutil and psutil.IOPRIO_CLASS_NONE:
+            #ionice
+            p = psutil.Process(os.getpid())
+            p.set_ionice(psutil.IOPRIO_CLASS_IDLE)
+            #nice
+            p.nice = 15
 
     def set_destination(self, destination, guid=(None, None)):
         """ Set the destination of the backup
@@ -162,9 +168,16 @@ class Vitalus:
         self.destination = destination
         self.guid = guid
 
-    #TODO: filter -> *filter ?
     def add_job(self, name, source, period=24, history=False, duration=50, keep=10, filter=None):
-        """ Add a new job
+        """
+        Deprecated
+        """
+        self.logger.critical('The method add_job is DEPRECATED. Use add_rsyncjob instead.')
+        self.add_rsyncjob(name, source, period=period, history=history, duration=duration, keep=keep, filter=filter)
+
+    #TODO: filter -> *filter ?
+    def add_rsyncjob(self, name, source, period=24, history=False, duration=50, keep=10, filter=None):
+        """ Add a rsync job
 
         :param name: backup label
         :type name: string
@@ -183,6 +196,8 @@ class Vitalus:
         :param filter: filters
         :type filter: tuple
 
+        :raises: ValueError -- if destination if not set
+
         .. note::
             filter syntax is the same of rsync. See "FILTER RULES" section
             in the rsync man page.
@@ -192,22 +207,51 @@ class Vitalus:
             None does not put a date in the path. Thus, it remains invariant.
         """
         if name in self.jobs:
-            self.critical("%s already present in the job list. Job's name should be uniq.", name)
+            self.logger.critical("%s already present in the job list. Job's name should be uniq.", name)
             return
 
-        if self.destination: #Raise something if it's None
+        if self.destination:
             period_in_seconds = period * 3600
-            self.logger.debug("add job: %s", name)
+            self.logger.debug("add rsync job: %s", name)
             try:
-                self.jobs.append(Job(self.backup_log_dir, name, source,
-                                     self.destination, period_in_seconds,
-                                     history, duration, keep, self.force,
-                                     self.guid, filter))
+                self.jobs.append(RsyncJob(self.backup_log_dir, self.destination, name, source,
+                                          period_in_seconds,
+                                          history, duration, keep, self.force,
+                                          self.guid, filter))
             except TARGETError as e:
                 # We abort this job
                 self.logger.error(e)
             except:
                 self.logger.exception('Exception raised in add_job()')
+        else:
+            raise ValueError('Destination not set')
+
+    def add_customjob(self, name, job, *args):
+        """
+        Add a custom job.
+
+        :param name: backup label
+        :type name: string
+        :param period: min time (hours) between backups
+        :type period: float
+        :param job: object representing a job
+        :param args: arguments to initialize the job
+        """
+        if name in self.jobs:
+            self.logger.critical("%s already present in the job list. Job's name should be uniq.", name)
+            return
+
+        if self.destination:
+            self.logger.debug("add custom job: %s", name)
+            try:
+                self.jobs.append(job(self.backup_log_dir, self.destination, name, *args))
+            except TARGETError as e:
+                # We abort this job
+                self.logger.error(e)
+            except:
+                self.logger.exception('Exception raised in add_job()')
+        else:
+            raise ValueError('Destination not set')
 
     def run(self):
         """ Run all jobs """
@@ -224,9 +268,9 @@ if __name__ == '__main__':
     b = Vitalus()
     b.set_log_level('DEBUG')
     b.set_destination('/tmp/sauvegarde')
-    b.add_job('test', '/home/gnu/tmp/firefox', period=0.0, history=True)
-    b.add_job('test2', '/home/gnu/tmp/debian', period=0.0, history=True)
-    b.add_job('test3', '/home/gnu/tmp/photos', period=0.001, history=False)
-    b.add_job('test4', '/home/gnu/tmp/www', period=0, history=True)
+    b.add_rsyncjob('test', '/home/gnu/tmp/firefox', period=0.0, history=True)
+    b.add_rsyncjob('test2', '/home/gnu/tmp/debian', period=0.0, history=True)
+    b.add_rsyncjob('test3', '/home/gnu/tmp/photos', period=0.001, history=False)
+    b.add_rsyncjob('test4', '/home/gnu/tmp/www', period=0, history=True)
 
     b.run()
